==> jc-1.4.5.tar.gz: javax/swing/plaf/metal/MetalTreeUI.h <==
// public class javax.swing.plaf.metal.MetalTreeUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class e35616e5ad8c6478 javax_swing_plaf_TreeUI
// @dep_class 2e70eed48a43960d javax_swing_plaf_basic_BasicTreeUI
// @dep_class 109838c67148a593 javax_swing_plaf_metal_MetalTreeUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTreeUI

#include "javax/swing/plaf/basic/BasicTreeUI.h"

#ifndef _JC_javax_swing_plaf_metal_MetalTreeUI_H_
#define _JC_javax_swing_plaf_metal_MetalTreeUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_plaf_metal_MetalTreeUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs	_jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs	_jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$refs	_jc_javax_swing_plaf_metal_MetalTreeUI$refs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs	_jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$object	_jc_javax_swing_plaf_metal_MetalTreeUI$object;

typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct	_jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct;
typedef const struct _jc_javax_swing_plaf_metal_MetalTreeUI$vmethods	_jc_javax_swing_plaf_metal_MetalTreeUI$vmethods;
typedef const struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtable	_jc_javax_swing_plaf_metal_MetalTreeUI$vtable;
typedef const struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtype	_jc_javax_swing_plaf_metal_MetalTreeUI$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct {
	struct _jc_javax_swing_plaf_metal_MetalTreeUI$object	*instance;
};
extern _jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct _jc_javax_swing_plaf_metal_MetalTreeUI$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_metal_MetalTreeUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalTreeUI$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_plaf_metal_MetalTreeUI$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_metal_MetalTreeUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_metal_MetalTreeUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TreeUI$vmethods	javax_swing_plaf_TreeUI;
	_jc_javax_swing_plaf_basic_BasicTreeUI$vmethods	javax_swing_plaf_basic_BasicTreeUI;
	_jc_javax_swing_plaf_metal_MetalTreeUI$vmethods	javax_swing_plaf_metal_MetalTreeUI;
};

// Vtype
struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_metal_MetalTreeUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$refs {
    _jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs	javax_swing_plaf_metal_MetalTreeUI;
    _jc_javax_swing_plaf_basic_BasicTreeUI$sub_refs	javax_swing_plaf_basic_BasicTreeUI;
    _jc_javax_swing_plaf_TreeUI$sub_refs	javax_swing_plaf_TreeUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TreeUI$sub_nonrefs	javax_swing_plaf_TreeUI;
    _jc_javax_swing_plaf_basic_BasicTreeUI$sub_nonrefs	javax_swing_plaf_basic_BasicTreeUI;
    _jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs	javax_swing_plaf_metal_MetalTreeUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_metal_MetalTreeUI$object {
	_jc_javax_swing_plaf_metal_MetalTreeUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_metal_MetalTreeUI$vtype	*vtype;
	_jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_metal_MetalTreeUI$vtype _jc_javax_swing_plaf_metal_MetalTreeUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_metal_MetalTreeUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_metal_MetalTreeUI$class_object;

#endif	/* _JC_javax_swing_plaf_metal_MetalTreeUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/metal/MetalTreeUI.h <==
// public class javax.swing.plaf.metal.MetalTreeUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class e35616e5ad8c6478 javax_swing_plaf_TreeUI
// @dep_class dc0158da73c44274 javax_swing_plaf_basic_BasicTreeUI
// @dep_class 197d510500e8e77d javax_swing_plaf_metal_MetalTreeUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicTreeUI

#include "javax/swing/plaf/basic/BasicTreeUI.h"

#ifndef _JC_javax_swing_plaf_metal_MetalTreeUI_H_
#define _JC_javax_swing_plaf_metal_MetalTreeUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs	_jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs	_jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$refs	_jc_javax_swing_plaf_metal_MetalTreeUI$refs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs	_jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$object	_jc_javax_swing_plaf_metal_MetalTreeUI$object;

typedef struct _jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct	_jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct;
typedef const struct _jc_javax_swing_plaf_metal_MetalTreeUI$vmethods	_jc_javax_swing_plaf_metal_MetalTreeUI$vmethods;
typedef const struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtable	_jc_javax_swing_plaf_metal_MetalTreeUI$vtable;
typedef const struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtype	_jc_javax_swing_plaf_metal_MetalTreeUI$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct {
	struct _jc_java_util_HashMap$object	*instances;
};
extern _jc_javax_swing_plaf_metal_MetalTreeUI$fields_struct _jc_javax_swing_plaf_metal_MetalTreeUI$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_metal_MetalTreeUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalTreeUI$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_plaf_metal_MetalTreeUI$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_metal_MetalTreeUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_metal_MetalTreeUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_TreeUI$vmethods	javax_swing_plaf_TreeUI;
	_jc_javax_swing_plaf_basic_BasicTreeUI$vmethods	javax_swing_plaf_basic_BasicTreeUI;
	_jc_javax_swing_plaf_metal_MetalTreeUI$vmethods	javax_swing_plaf_metal_MetalTreeUI;
};

// Vtype
struct _jc_javax_swing_plaf_metal_MetalTreeUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_metal_MetalTreeUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$refs {
    _jc_javax_swing_plaf_metal_MetalTreeUI$sub_refs	javax_swing_plaf_metal_MetalTreeUI;
    _jc_javax_swing_plaf_basic_BasicTreeUI$sub_refs	javax_swing_plaf_basic_BasicTreeUI;
    _jc_javax_swing_plaf_TreeUI$sub_refs	javax_swing_plaf_TreeUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_TreeUI$sub_nonrefs	javax_swing_plaf_TreeUI;
    _jc_javax_swing_plaf_basic_BasicTreeUI$sub_nonrefs	javax_swing_plaf_basic_BasicTreeUI;
    _jc_javax_swing_plaf_metal_MetalTreeUI$sub_nonrefs	javax_swing_plaf_metal_MetalTreeUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_metal_MetalTreeUI$object {
	_jc_javax_swing_plaf_metal_MetalTreeUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_metal_MetalTreeUI$vtype	*vtype;
	_jc_javax_swing_plaf_metal_MetalTreeUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_metal_MetalTreeUI$vtype _jc_javax_swing_plaf_metal_MetalTreeUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_metal_MetalTreeUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_metal_MetalTreeUI$class_object;

#endif	/* _JC_javax_swing_plaf_metal_MetalTreeUI_H_ */
